##  How Can I See the Current Version?
The current version can be viewed by clicking on About SAP LeanIX in the main menu located at the top right corner of the workspace.
![View current version](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27437b1d7a441014a1ddf4d750223dd4_LowRes.png)
View Current Version
